
from setuptools import setup

setup(package_data={'lupa-stubs': ['__init__.pyi', 'lua51.pyi', 'lua52.pyi', 'lua53.pyi', 'lua54.pyi', 'luajit20.pyi', 'luajit21.pyi', 'version.pyi', 'METADATA.toml', 'py.typed']})
